<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author mubaidillah <mubaidillah@gmail.com>
 * @author Yustinus Waruwu <juswaruwu@gmail.com>
 */
$lang['admin_acl']             = 'Manajemen Daftar Pengendali Akses';
$lang['acl_group']             = 'Grup:';
$lang['acl_user']              = 'User:';
$lang['acl_perms']             = 'Ijin untuk';
$lang['page']                  = 'Halaman';
$lang['namespace']             = 'Namespace';
$lang['btn_select']            = 'Pilih';
$lang['acl_perm1']             = 'Baca';
$lang['acl_perm2']             = 'Ubah';
$lang['acl_perm4']             = 'Buat';
$lang['acl_perm8']             = 'Upload';
$lang['acl_perm16']            = 'Hapus';
$lang['acl_new']               = 'Tambah Entry baru';
